@@ -89,13 +89,22 @@ class AD:
         out_format="json",
         sep=";",
     ):
-        self._conn = _get_connection(host, port, use_ssl, sso, user, password)
+        try:
+            self._conn = _get_connection(host, port, use_ssl, sso, user, password)
+        except:
+            logging.error("Cannot loging to Active Directory. Bye")
+            sys.exit(1)
         self._attributes = attributes
         self._sep = sep
         self._search_base = search_base
         self._limit = limit
         self._out_format = out_format
 
+    def change_password(self, user_name=None, user_dn=None):
+        return msad.user.change_password(
+            self._conn, self._search_base, user_name, user_dn
+        )
+
     def search(self, search_filter):
         self._conn.search(
             self._search_base,
